summaryrefslogtreecommitdiffstats
path: root/Source/cmQTWrapCPPCommand.h
diff options
context:
space:
mode:
Diffstat (limited to 'Source/cmQTWrapCPPCommand.h')
-rw-r--r--Source/cmQTWrapCPPCommand.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/Source/cmQTWrapCPPCommand.h b/Source/cmQTWrapCPPCommand.h
index 46d50d3..6f3e95d 100644
--- a/Source/cmQTWrapCPPCommand.h
+++ b/Source/cmQTWrapCPPCommand.h
@@ -83,13 +83,13 @@ private:
/**
* List of produced files.
*/
- std::vector<cmSourceFile> m_WrapClasses;
+ std::vector<cmSourceFile> WrapClasses;
/**
* List of header files that pprovide the source for m_WrapClasses.
*/
- std::vector<std::string> m_WrapHeaders;
- std::string m_LibraryName;
- std::string m_SourceList;
+ std::vector<std::string> WrapHeaders;
+ std::string LibraryName;
+ std::string SourceList;
};
@@ -83,13 +83,13 @@ private:
/**
- * List of header files that pprovide the source for m_WrapClasses.
+ * List of header files that pprovide the source for WrapClasses.
*/